@@ -7,3 +7,5 @@ PORT = getattr(settings, 'ELASTIC_PORT', 9200)
 USE_SSL = getattr(settings, 'ELASTIC_USE_SSL', False)
 CURRENT_TIME_ZONE = tz.gettz(getattr(settings, 'TIME_ZONE', 'UTC'))
 ALLOWED_STATUS = getattr(settings, 'ELASTIC_ALLOWED_STATUS', [])
+USER = getattr(settings, 'ELASTIC_USER', '')
+SECRET = getattr(settings, 'ELASTIC_PASSWORD', '')
